@@ -24,17 +24,19 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <QTimer>
 
 // KDE
-#include <KDebug>
-#include <KIO/NetAccess>
+#include <KIO/StatJob>
+#include <KIO/DeleteJob>
+#include <KIO/MkdirJob>
+#include <KIO/FileCopyJob>
+#include <KJobWidgets>
 #include <KStandardDirs>
 #include <QStandardPaths>
 
 QUrl setUpRemoteTestDir(const QString& testFile)
 {
     QWidget* authWindow = 0;
-    bool ok;
     if (qgetenv("GV_REMOTE_TESTS_BASE_URL").isEmpty()) {
-        kWarning() << "Environment variable GV_REMOTE_TESTS_BASE_URL not set: remote tests disabled";
+        qWarning() << "Environment variable GV_REMOTE_TESTS_BASE_URL not set: remote tests disabled";
         return QUrl();
     }
 
@@ -42,12 +44,19 @@ QUrl setUpRemoteTestDir(const QString& testFile)
     baseUrl = baseUrl.adjusted(QUrl::StripTrailingSlash);
     baseUrl.setPath(baseUrl.path() + "/gwenview-remote-tests");
 
-    if (KIO::NetAccess::exists(baseUrl, KIO::NetAccess::DestinationSide, authWindow)) {
-        KIO::NetAccess::del(baseUrl, authWindow);
+    KIO::StatJob *statJob = KIO::stat(baseUrl, KIO::StatJob::DestinationSide, 0);
+    KJobWidgets::setWindow(statJob, authWindow);
+
+    if (statJob->exec()) {
+        KIO::DeleteJob *deleteJob = KIO::del(baseUrl);
+        KJobWidgets::setWindow(deleteJob, authWindow);
+        deleteJob->exec();
     }
-    ok = KIO::NetAccess::mkdir(baseUrl, authWindow);
-    if (!ok) {
-        kFatal() << "Could not create dir" << baseUrl << ":" << KIO::NetAccess::lastErrorString();
+
+    KIO::MkdirJob *mkdirJob = KIO::mkdir(baseUrl);
+    KJobWidgets::setWindow(mkdirJob, authWindow);
+    if (!mkdirJob->exec()) {
+        qCritical() << "Could not create dir" << baseUrl << ":" << mkdirJob->errorString();
         return QUrl();
     }
 
@@ -55,9 +64,10 @@ QUrl setUpRemoteTestDir(const QString& testFile)
         QUrl dstUrl = baseUrl;
         dstUrl = dstUrl.adjusted(QUrl::StripTrailingSlash);
         dstUrl.setPath(dstUrl.path() + '/' + testFile);
-        ok = KIO::NetAccess::file_copy(urlForTestFile(testFile), dstUrl, authWindow);
-        if (!ok) {
-            kFatal() << "Could not copy" << testFile << "to" << dstUrl << ":" << KIO::NetAccess::lastErrorString();
+        KIO::FileCopyJob *copyJob = KIO::file_copy(urlForTestFile(testFile), dstUrl);
+        KJobWidgets::setWindow(copyJob, authWindow);
+        if (!copyJob->exec()) {
+            qCritical() << "Could not copy" << testFile << "to" << dstUrl << ":" << copyJob->errorString();
             return QUrl();
         }
     }
@@ -90,21 +100,9 @@ void purgeUserConfiguration()
     QString confDir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
     QVERIFY(confDir.endsWith(".qttest/share")); // Better safe than sorry
     if (QFileInfo(confDir).isDir()) {
-        bool ok = KIO::NetAccess::del(QUrl::fromLocalFile(confDir), 0);
-        QVERIFY(ok);
+        KIO::DeleteJob *deleteJob = KIO::del(QUrl::fromLocalFile(confDir));
+        QVERIFY(deleteJob->exec());
     }
-
-    QFile kdebugrc(KStandardDirs::locateLocal("config", "kdebugrc"));
-    QVERIFY(kdebugrc.open(QIODevice::WriteOnly));
-    kdebugrc.write(
-        "DisableAll=true\n"
-        "InfoOutput=4\n"
-        "[gwenview]\n"
-        "InfoOutput=2\n"
-        "[gwenview_importer]\n"
-        "InfoOutput=2\n"
-        );
-    kClearDebugConfig();
 }
 
 static QImage simplifyFormats(const QImage& img)
@@ -126,13 +124,13 @@ inline bool fuzzyColorComponentCompare(int c1, int c2, int delta)
 bool fuzzyImageCompare(const QImage& img1_, const QImage& img2_, int delta)
 {
     if (img1_.size() != img2_.size()) {
-        kWarning() << "Different sizes" << img1_.size() << "!=" << img2_.size();
+        qWarning() << "Different sizes" << img1_.size() << "!=" << img2_.size();
         return false;
     }
     QImage img1 = simplifyFormats(img1_);
     QImage img2 = simplifyFormats(img2_);
     if (img1.format() != img2.format()) {
-        kWarning() << "Different formats" << img1.format() << "!=" << img2.format();
+        qWarning() << "Different formats" << img1.format() << "!=" << img2.format();
         return false;
     }
 
@@ -146,7 +144,7 @@ bool fuzzyImageCompare(const QImage& img1_, const QImage& img2_, int delta)
                 && fuzzyColorComponentCompare(col1.blue(), col2.blue(), delta)
                 && fuzzyColorComponentCompare(col1.alpha(), col2.alpha(), delta);
             if (!ok) {
-                kWarning() << "Different at" << QPoint(posX, posY) << col1.name() << "!=" << col2.name();
+                qWarning() << "Different at" << QPoint(posX, posY) << col1.name() << "!=" << col2.name();
                 return false;
             }
         }
